<?php

/**
 * @file
 */
namespace Drupal\edlp_corpus\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Creates a 'Entrees' Block
 * @Block(
 * id = "block_edlp_entrees",
 * admin_label = @Translation("Edlp entrees block"),
 * )
 */
class BlockEntrees extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {

    $query = \Drupal::entityQuery('taxonomy_term')
      ->condition('vid', 'entrees');

    $tids = $query->execute();
    $terms = entity_load_multiple('taxonomy_term', $tids);
    // dsm($terms);
    foreach ($terms as $term) {
      // dpm($term->toArray());

      $tid = $term->id();
      $name = $term->getName();

      $term_url = Url::fromRoute('entity.taxonomy_term.canonical', ['taxonomy_term' => $tid]);
      $term_link = Link::fromTextAndUrl($name, $term_url)->toRenderable();
      $term_link['#prefix'] = '<span class="oblique-wrapper">';
      $term_link['#suffix'] = "</span>";
      $term_link["#attributes"] = array(
        "class" => array('term-'.$term->id(), 'term-link'),
        "tid" => $term->id()
      );

      $index_url = Url::fromRoute('entity.taxonomy_term.canonical', ['taxonomy_term' => $tid]);
      $index_link = Link::fromTextAndUrl('index', $index_url)->toRenderable();
      $index_link['#prefix'] = '<span class="oblique-wrapper">';
      $index_link['#suffix'] = "</span>";
      $index_link['#attributes'] = array(
        'class' => array('index-link'),
        "tid" => $term->id()
      );


      $notice_url = Url::fromRoute('entity.taxonomy_term.canonical', ['taxonomy_term' => $tid]);
      $notice_link = Link::fromTextAndUrl('notice', $notice_url)->toRenderable();
      $notice_link['#prefix'] = '<span class="oblique-wrapper">';
      $notice_link['#suffix'] = "</span>";
      $notice_link['#attributes'] = array(
        'class' => array('notice-link'),
        "tid" => $term->id()
      );

      $description = $term->get('description')->value;
      // dpm($description);

      // TODO: output block through twig and preprocess function
      // TODO: load corpus map libraries only with this block
      $entree = array(
        '#wrapper_attributes' => array(
          'class' => array('term-'.$term->id(), 'entree'),
          'tid' => $term->id()
        ),
        'term_link' => $term_link,
        'entree_content' => array(
          '#type' => 'container',
          '#attributes' => array(
            'class' => 'entree-content'
          ),
          'index_link' => $index_link,
          'notice_link' => $notice_link,
          'description' => array(
            '#type' => 'container',
            '#markup' => $description,
            '#attributes' => array('class'=>'term-description')
          )
        )
      );

      // if (isset($entrees) && count($entrees) == count($terms)-3) {
      //   $entree['#wrapper_attributes']['class'][] = 'opened';
      // }

      // dpm($entree);

      $entrees[] = $entree;
    }

    return array (
      '#theme' => 'item_list',
      '#items' => $entrees,
    );
  }

}
